-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009 - 2016 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

local Stats = require "engine.interface.ActorStats"
local Particles = require "engine.Particles"
local Entity = require "engine.Entity"
local Chat = require "engine.Chat"
local Map = require "engine.Map"
local Level = require "engine.Level"

TemporaryEffects.tempeffect_def.EFF_BLOCKING.long_desc = function(self, eff) return ("Absorbs up to %d damage from blockable attacks."):format(eff.power) end
TemporaryEffects.tempeffect_def.EFF_BLOCKING.do_block = function(type, dam, eff, self, src)
		local dur_inc = 0
		local crit_inc = 0
		local nb = 1
		if self:knowTalent(self.T_RIPOSTE) then
			local t = self:getTalentFromId(self.T_RIPOSTE)
			dur_inc = t.getDurInc(self, t)
			crit_inc = t.getCritInc(self, t)
			nb = nb + dur_inc
		end
		local block = eff.power
		if type ~= DamageType.PHYSICAL then
			if not (self.block_extra_types and self.block_extra_types[type]) then block = math.min(block, block * self:combatSpellResist() / 100 * (1 + (self.combat_spellresist_blockmult or 0))) end
		end
		local amt = util.bound(dam - block, 0, dam)
		-- Sacrifice the block effect?
		if dam >= self.max_life*0.5 then
			amt = 0
			if not self:knowTalent(self.T_ETERNAL_GUARD) then
				eff.dur = 0
				src:logCombat(self, "#Target# blocks the whole attack, but their guard is broken!")
			else
				src:logCombat(self, "#Target# blocks the whole attack, and their guard is unbroken!")
			end
		end
		local blocked = dam - amt
		--eff.totalblocked = blocked
		--eff.power = eff.power - blocked
		--if eff.power <= 0 then eff.dur = 0 end
		local shield1, combat1, shield2, combat2 = self:hasShield()
		if shield1 and shield1.on_block then
			local specials = shield1.on_block
			if specials.fct then specials = {specials} end
			for _, special in ipairs(specials) do
				if special.fct and (not src.dead or special.on_kill) then
					special.fct(shield1, self, src, type, dam, eff)
				end
			end
		end
		if shield2 and shield2.on_block then
			local specials = shield2.on_block
			if specials.fct then specials = {specials} end
			for _, special in ipairs(specials) do
				if special.fct and (not src.dead or special.on_kill) then
					special.fct(shield2, self, src, type, dam, eff)
				end
			end
		end
		if eff.properties.br then
			self:heal(blocked, src)
			game:delayedLogMessage(self, src, "block_heal", "#CRIMSON##Source# heals from blocking with %s shield!", string.his_her(self))
		end
		if eff.properties.ref and src.life then DamageType.defaultProjector(src, src.x, src.y, type, blocked, tmp, true) end
		if (self:knowTalent(self.T_RIPOSTE) or amt == 0) and src.life then
			src:setEffect(src.EFF_COUNTERSTRIKE, (1 + dur_inc) * math.max(1, (src.global_speed or 1)), {power=eff.power, no_ct_effect=true, src=self, crit_inc=crit_inc, nb=nb})
			if eff.properties.sb then
				if src:canBe("disarm") then
					src:setEffect(src.EFF_DISARMED, 3, {apply_power=self:combatPhysicalpower()})
				else
					game.logSeen(src, "%s resists the disarming attempt!", src.name:capitalize())
				end
			end
			if eff.properties.on_cs then
				eff.properties.on_cs(self, eff, dam, type, src)
			end
		end-- specify duration here to avoid stacking for high speed attackers

		self:fireTalentCheck("callbackOnBlock", eff, dam, type, src)

		return amt
	end
TemporaryEffects.tempeffect_def.EFF_BLOCKING.activate = function(self, eff)
		eff.tmpid = self:addTemporaryValue("block", eff.power)
		eff.def = self:addTemporaryValue("combat_def", -eff.power)
		eff.ctdef = self:addTemporaryValue("combat_def_ct", eff.power)
		if self.stats_on_block then 
			for a, b in pairs(self.stats_on_block) do
				self:effectTemporaryValue(eff, a, b)
			end
		end
		--if eff.properties.sp then eff.spell = self:addTemporaryValue("combat_spellresist", eff.power) end
		if self:knowTalent(self.T_SHIELD_EXPERTISE) then
			local t = self:getTalentFromId(self.T_SHIELD_EXPERTISE)
			local saves = t.saves_factor(self, t) * eff.power
			self:effectTemporaryValue(eff, "combat_spellresist", saves)
			self:effectTemporaryValue(eff, "combat_physresist", saves)
		end
		--eff.totalblocked = 0
	end
TemporaryEffects.tempeffect_def.EFF_BLOCKING.deactivate = function(self, eff)
		self:removeTemporaryValue("block", eff.tmpid)
		self:removeTemporaryValue("combat_def", eff.def)
		self:removeTemporaryValue("combat_def_ct", eff.ctdef)
		--if eff.properties.sp then self:removeTemporaryValue("combat_spellresist", eff.spell) end
	end
TemporaryEffects.tempeffect_def.EFF_BLOCKING.charges = function(self, eff)
   return math.floor(eff.power)
end

newEffect{
	name = "UNNERVED", image = "effects/confused.png",
	desc = "Unnerved",
	long_desc = function(self, eff) return ("The target is unnerved, reducing their accuracy and mindpower by %d."):format(eff.power) end,
	type = "mental",
	subtype = { confusion=true },
	status = "detrimental",
	parameters = { power=50 },
	on_gain = function(self, err) return "#Target# loses courage.", "+Unnerved" end,
	on_lose = function(self, err) return "#Target# seems more couragious.", "-Unnerved" end,
	activate = function(self, eff)
		self:effectTemporaryValue(eff, "combat_atk", -eff.power)
		self:effectTemporaryValue(eff, "combat_mindpower", -eff.power)
	end,
	deactivate = function(self, eff)
	end,
}	
	
	
