-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009 - 2016 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Nicolas Casalini "DarkGod"
-- darkgod@te4.org

local Stats = require "engine.interface.ActorStats"
local Talents = require "engine.interface.ActorTalents"
local DamageType = require "engine.DamageType"

--load("/data/general/objects/egos/charged-attack.lua")
--load("/data/general/objects/egos/charged-defensive.lua")
--load("/data/general/objects/egos/charged-utility.lua")

----------------------------------------------------------------
-- Technique Lesser Egos
----------------------------------------------------------------
newEntity{
	power_source = {technique=true},
	name = " of grave resistance", suffix=true, instant_resolve=true,
	keywords = {grave=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={
			[DamageType.COLD] = resolvers.mbonus_material(15, 15),
			[DamageType.DARKNESS] = resolvers.mbonus_material(15, 15),
		},
	},
}
newEntity{
	power_source = {technique=true},
	name = " of solar resistance", suffix=true, instant_resolve=true,
	keywords = {solar=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={
			[DamageType.FIRE] = resolvers.mbonus_material(15, 15),
			[DamageType.LIGHT] = resolvers.mbonus_material(15, 15),
		},
	},
}
newEntity{
	power_source = {technique=true},
	name = "reinforced ", prefix=true, instant_resolve=true,
	keywords = {reinforced=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		block = resolvers.mbonus_material(8, 2),
	},
	wielder = {
		combat_armor = resolvers.mbonus_material(8, 4),
	},
}
newEntity{
	power_source = {technique=true},
	name = "deflecting ", prefix=true, instant_resolve=true,
	keywords = {deflection=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		combat_def=resolvers.mbonus_material(11, 4),
		projectile_evasion=resolvers.mbonus_material(15, 4),
		projectile_evasion_spread=1,
	},
}
newEntity{
	power_source = {technique=true},
	name = "spiked ", prefix=true, instant_resolve=true,
	keywords = {spiked=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		melee_project={[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10)},
	},
}
newEntity{
	power_source = {technique=true},
	name = "snagging ", prefix=true, instant_resolve=true,
	keywords = {snagging=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		disarm_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
	},
	on_block = {desc = "Attacker is disarmed", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			if target:canBe("disarm") then
				target:setEffect(target.EFF_DISARM, 4, {src=who, apply_power=who:combatAttack(combat)})
			end
	end,},
}
newEntity{
	power_source = {technique=true},
	name = "stable ", prefix=true, instant_resolve=true,
	keywords = {stable=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		knockback_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
		combat_physresist = resolvers.mbonus_material(10, 5),
	},
}
newEntity{
	power_source = {technique=true},
	name = "quicksilver ", prefix=true, instant_resolve=true,
	keywords = {quicksilver=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		pin_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
		fatigue = resolvers.mbonus_material(10, 2, function(e, v) return 0, -v end),
	},
}

----------------------------------------------------------------
-- Technique Greater Egos
----------------------------------------------------------------
newEntity{
	power_source = {technique=true},
	name = " of storm resistance", suffix=true, instant_resolve=true,
	keywords = {storm=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.COLD] = resolvers.mbonus_material(15, 15),
			[DamageType.LIGHTNING] = resolvers.mbonus_material(15, 15),
		},
		stun_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
	},
}
newEntity{
	power_source = {technique=true},
	name = " of burn resistance", suffix=true, instant_resolve=true,
	keywords = {burn=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.ACID] = resolvers.mbonus_material(15, 15),
			[DamageType.FIRE] = resolvers.mbonus_material(15, 15),
		},
		blind_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
	},
}
newEntity{
	power_source = {technique=true},
	name = " of mirroring", suffix=true, instant_resolve=true,
	keywords = {reflection=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	wielder = {
		resists={
			[DamageType.LIGHT] = resolvers.mbonus_material(10, 10),
			[DamageType.DARKNESS] = resolvers.mbonus_material(10, 10),
			[DamageType.MIND] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {technique=true},
	name = "skirmisher's ", prefix=true, instant_resolve=true,
	keywords = {skirmishers=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		block = resolvers.mbonus_material(8, 2),
	},
	wielder = {
		inc_stats = {
			[Stats.STAT_DEX] = resolvers.mbonus_material(5, 1),
		},
		fatigue = resolvers.mbonus_material(10, 2, function(e, v) return 0, -v end),
	},
}
newEntity{
	power_source = {technique=true},
	name = "impervious ", prefix=true, instant_resolve=true,
	keywords = {impervious=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		block = resolvers.mbonus_material(9, 3),
	},
	wielder = {
		combat_armor = resolvers.mbonus_material(8, 4),
		combat_physresist = resolvers.mbonus_material(10, 5),
		combat_armor_hardiness = 10,
	},
}
newEntity{
	power_source = {technique=true},
	name = " of crushing", suffix=true, instant_resolve=true,
	keywords = {crushing=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		dam = resolvers.mbonus_material(5, 5),
		-- Just a retheme of Crippling, most of the weapon egos aren't getting copied though
		special_on_crit = {desc="smash the target with your shield crippling them", fct=function(combat, who, target)
			target:setEffect(target.EFF_CRIPPLE, 4, {src=who, apply_power=who:combatAttack(combat)})
		end},
	},
	wielder = {
		combat_dam = resolvers.mbonus_material(5, 5),
		combat_physcrit = resolvers.mbonus_material(3, 3),
	},
}
newEntity{
	power_source = {technique=true},
	name = "bladed ", prefix=true, instant_resolve=true,
	keywords = {bladed=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project={[DamageType.PHYSICALBLEED] = resolvers.mbonus_material(20, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.PHYSICALBLEED] = resolvers.mbonus_material(20, 10)},
		combat_physcrit = resolvers.mbonus_material(3, 3),
	},
}

----------------------------------------------------------------
-- Psionic Lesser Egos
----------------------------------------------------------------
newEntity{
	power_source = {psionic=true},
	name = " of mind resistance (#RESIST#)", suffix=true, instant_resolve=true,
	keywords = {mind=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={[DamageType.MIND] = resolvers.mbonus_material(10, 10)},
		stats_on_block={combat_mentalresist = resolvers.mbonus_material(40, 10)}
	},
}
newEntity{
	power_source = {psionic=true},
	name = "gloomy ", prefix=true, instant_resolve=true,
	keywords = {gloomy=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		on_melee_hit={[DamageType.ITEM_MIND_GLOOM] = resolvers.mbonus_material(25, 10)},
		melee_project={
			[DamageType.ITEM_MIND_GLOOM] = resolvers.mbonus_material(10, 5),
		},
	},
}
newEntity{
	power_source = {psionic=true},
	name = "resonating ", prefix=true, instant_resolve=true,
	keywords = {resonating=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		damage_resonance = resolvers.mbonus_material(20, 5),
	},
	on_block = {desc = "Attacker is thrown off balance", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			target:setEffect(target.EFF_OFF_BALANCE, 4, {src=who, apply_power=who:combatAttack(combat)})
	end,},
}
newEntity{
	power_source = {psionic=true},
	name = "raging ", prefix=true, instant_resolve=true,
	keywords = {raging=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	special_combat = {
		burst_on_crit={[DamageType.LIGHTNING] = resolvers.mbonus_material(40, 10)},
	},
	wielder = {
		hate_regen_when_hit = resolvers.mbonus_material(1, 1, function(e, v) v=v/10 return 0, v end),
		combat_critical_power = resolvers.mbonus_material(40, 10),
	},
}
newEntity{
	power_source = {psionic=true},
	name = "unnerving ", prefix=true, instant_resolve=true,
	keywords = {unnerving=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	on_block = {desc = "Attacker is unnerved, reducing their mindpower and accuracy", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			target:setEffect(target.EFF_UNNERVED, 4, {src=who, power=20, apply_power=who:combatMindpower(combat)})
	end,},
}
newEntity{
	power_source = {psionic=true},
	name = " of dreams", suffix=true, instant_resolve=true,
	keywords = {dreams=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	special_combat = {
		melee_project={[DamageType.MIND] = resolvers.mbonus_material(10, 10)},
	},
	on_block = {desc = "Attacker is put to sleep (power scales with willpower)", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			if target:canBe("disarm") then
				local power = who:getStat("wil")
				target:setEffect(target.EFF_SLEEP, 4, {src=who, apply_power=who:combatMindpower(combat), power=10, power=10, waking=0, contagious=0})
			end
	end,},
}

----------------------------------------------------------------
-- Psionic Greater Egos
----------------------------------------------------------------
newEntity{
	power_source = {psionic=true},
	name = "sentient ", prefix=true, instant_resolve=true,
	keywords = {sentient=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		block = resolvers.mbonus_material(9, 3),
	},
	wielder = {
		combat_def = resolvers.mbonus_material(12, 6),
		combat_armor_hardiness = 10,
	},
}
newEntity{
	power_source = {psionic=true},
	name = "dreamforged ", prefix=true, instant_resolve=true,
	keywords = {dreamforge=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		melee_project={[DamageType.FIRE] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		on_melee_hit = {[DamageType.FIRE] = resolvers.mbonus_material(10, 10)},
		inc_stats = {
			[Stats.STAT_WIL] = resolvers.mbonus_material(5, 1),
		},
		stats_on_block={psi_regen_when_hit = resolvers.mbonus_material(20, 2)},
	},
}
newEntity{
	power_source = {psionic=true},
	name = " of vengeance", suffix=true, instant_resolve=true,
	keywords = {vengeance=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		melee_project={[DamageType.DARKNESS] = resolvers.mbonus_material(10, 10)},
		reflective = true,
	},
	wielder = {
		on_melee_hit = {[DamageType.DARKNESS] = resolvers.mbonus_material(10, 10)},
	},
}
newEntity{
	power_source = {psionic=true},
	name = "nightmarish ", prefix=true, instant_resolve=true,
	keywords = {nightmarish=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project={[DamageType.ITEM_DARKNESS_NUMBING] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		combat_mindpower = resolvers.mbonus_material(10, 10),
		on_melee_hit = {[DamageType.ITEM_DARKNESS_NUMBING] = resolvers.mbonus_material(10, 10)},
	},
}
newEntity{
	power_source = {psionic=true},
	name = " of telekinesis", suffix=true, instant_resolve=true,
	keywords = {kinetic=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.ACID] = resolvers.mbonus_material(15, 15),
			[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10),
		},
		combat_physresist = resolvers.mbonus_material(10, 10),
	},
}
newEntity{
	power_source = {psionic=true},
	name = " of thermokinesis", suffix=true, instant_resolve=true,
	keywords = {thermo=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.FIRE] = resolvers.mbonus_material(15, 15),
			[DamageType.COLD] = resolvers.mbonus_material(15, 15),
		},
		resists={},
		combat_spellresist = resolvers.mbonus_material(10, 10),
	},
}
newEntity{
	power_source = {psionic=true},
	name = " of electrokinesis", suffix=true, instant_resolve=true,
	keywords = {electro=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.LIGHTNING] = resolvers.mbonus_material(15, 15),
			[DamageType.MIND] = resolvers.mbonus_material(15, 15),
		},
		combat_mentalresist = resolvers.mbonus_material(10, 10),
	},
}

----------------------------------------------------------------
-- Nature Lesser Egos
----------------------------------------------------------------
newEntity{
	power_source = {nature=true},
	name = " of temporal resistance (#RESIST#)", suffix=true, instant_resolve=true,
	keywords = {temporal=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10)},
		on_melee_hit={[DamageType.ITEM_TEMPORAL_ENERGIZE] = resolvers.mbonus_material(25, 10)},
	},
}
newEntity{
	power_source = {nature=true},
	name = "living ", prefix=true, instant_resolve=true,
	keywords = {living=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		resists={
			[DamageType.NATURE] = resolvers.mbonus_material(10, 10),
		},
		max_life = resolvers.mbonus_material(70, 40),
		on_melee_hit = {
			[DamageType.NATURE] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = "shocking ", prefix=true, instant_resolve=true,
	keywords = {shocking=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		melee_project={[DamageType.ITEM_LIGHTNING_DAZE] = resolvers.mbonus_material(25, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.LIGHTNING] = resolvers.mbonus_material(20, 10)},
		resists={
			[DamageType.ACID] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = "acidic ", prefix=true, instant_resolve=true,
	keywords = {acidic=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		melee_project={[DamageType.ITEM_ACID_CORRODE] = resolvers.mbonus_material(20, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.ACID] = resolvers.mbonus_material(25, 10)},
		resists={
			[DamageType.LIGHTNING] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = " of earthen support", suffix=true, instant_resolve=true,
	keywords = {['e. support']=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		resists={[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10)},
		stats_on_block={combat_physresist = resolvers.mbonus_material(40, 10)}
	},
}
newEntity{
	power_source = {nature=true},
	name = "wooden ", prefix=true, instant_resolve=true,
	keywords = {wooden=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 0,
	wielder = {
		fatigue = resolvers.mbonus_material(10, 2, function(e, v) return 0, -v end),
		combat_def_ranged = resolvers.mbonus_material(10, 5),
	},
}

----------------------------------------------------------------
-- Nature Greater Egos
----------------------------------------------------------------
newEntity{
	power_source = {nature=true},
	name = " of purity", suffix=true, instant_resolve=true,
	keywords = {purity=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	resolvers.charmt(Talents.T_WATERS_OF_LIFE, {2,3,4,5}, 30 ),
	wielder = {
		resists={
			[DamageType.NATURE] = resolvers.mbonus_material(10, 10),
			[DamageType.BLIGHT] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = "flaming ", prefix=true, instant_resolve=true,
	keywords = {flaming=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		burst_on_hit={[DamageType.FIRE] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.FIRE] = resolvers.mbonus_material(10, 10)},
		resists={
			[DamageType.COLD] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = "icy ", prefix=true, instant_resolve=true,
	keywords = {icy=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project={[DamageType.COLD] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		on_melee_hit={[DamageType.ICE] = resolvers.mbonus_material(10, 10)},
		resists={
			[DamageType.FIRE] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {nature=true},
	name = "blood-etched ", prefix=true, instant_resolve=true,
	keywords = {['b. etched']=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		bloodruned = true,
	},
	wielder = {
		life_regen = resolvers.mbonus_material(5, 1),
	},
}
newEntity{
	power_source = {nature=true},
	name = "cyclonic ", prefix=true, instant_resolve=true,
	keywords = {cyclonic=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		projectile_evasion=resolvers.mbonus_material(15, 5),
		movement_speed=resolvers.mbonus_material(10, 10, function(e, v) return 0, v/100 end),
	},
	charm_power = resolvers.mbonus_material(9, 4),
	charm_power_def = {add=1, max=50, floor=true},
	resolvers.charm("redirect nearby projectiles back to their source (rad %d)", 15, function(self, who)
		local grids = core.fov.circle_grids(who.x, who.y, self:getCharmPower(who), true)
		for x, yy in pairs(grids) do for y, _ in pairs(grids[x]) do
			local i = 0
			local p = game.level.map(x, y, Map.PROJECTILE+i)
			while p do
				if p.project and p.project.def.typ.source_actor ~= who then
					p.project.def.typ.line_function = core.fov.line(p.x, p.y, p.project.def.typ.source_actor.x, p.project.def.typ.source_actor.y)
				end
				i = i + 1
				p = game.level.map(x, y, Map.PROJECTILE+i)
			end
		end end
		game.logSeen(who, "%s uses %s!", who.name:capitalize(), self:getName{no_count=true})
		return {id=true, used=true}
	end),
}
newEntity{
	power_source = {nature=true},
	name = " of earthen fury", suffix=true, instant_resolve=true,
	keywords = {['e. fury']=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		burst_on_hit={[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10)},
	},
	wielder = {
		resists={[DamageType.PHYSICAL] = resolvers.mbonus_material(10, 10)},
	},
	on_block = {desc = "If this damage hit ends your block, release all blocked damage as a radius 2 physical damage explosion.", fct = function(self, who, target, type, dam, eff)
		if not eff.dur then return end
		if who.turn_procs and who.turn_procs.earthen_fury then return end

		-- Set this *before* damage or reflect/martyr avoids the limit
		if not who.turn_procs.earthen_fury then who.turn_procs.earthen_fury = true end
		
		local tg = {type="ball", range=0, radius=2}
		local damage = dam

		who:project(tg, who.x, who.y, engine.DamageType.PHYSICAL, damage)
		game.level.map:particleEmitter(who.x, who.y, 2, "ball_earth", {radius=2})
		who:logCombat("#Source# unleashes earthen retribution!")
	end,},
}
newEntity{
	power_source = {nature=true},
	name = " of harmony", suffix=true, instant_resolve=true,
	keywords = {harmony=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.ACID] = resolvers.mbonus_material(8, 5),
			[DamageType.LIGHTNING] = resolvers.mbonus_material(8, 5),
			[DamageType.FIRE] = resolvers.mbonus_material(8, 5),
			[DamageType.COLD] = resolvers.mbonus_material(8, 5),
			[DamageType.NATURE] = resolvers.mbonus_material(8, 5),
		},
		stats_on_block={equilibrium_regen_when_hit = resolvers.mbonus_material(20, 2, function(e, v) return 0, -v end)},
	},
}
newEntity{
	power_source = {nature=true},
	name = "wyrm scaled ", prefix=true, instant_resolve=true,
	keywords = {wyrmscaled=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		block = resolvers.mbonus_material(9, 3),
	},
	wielder = {
		combat_armor = resolvers.mbonus_material(8, 4),
		stun_immune = resolvers.mbonus_material(25, 15, function(e, v) return 0, v/100 end),
		blind_immune = resolvers.mbonus_material(25, 15, function(e, v) return 0, v/100 end),
	},
}

----------------------------------------------------------------
-- Arcane Lesser Egos
----------------------------------------------------------------
newEntity{
	power_source = {arcane=true},
	name = "scorching ", prefix=true, instant_resolve=true,
	keywords = {scorching=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		melee_project = {
			[DamageType.FIRE] = resolvers.mbonus_material(20, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.FIRE] = resolvers.mbonus_material(10, 10),
		},
		stats_on_block={
			on_melee_hit = {
				[DamageType.FIREBURN] = resolvers.mbonus_material(30, 20),
			},
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "wintry ", prefix=true, instant_resolve=true,
	keywords = {wintry=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	special_combat = {
		melee_project = {
			[DamageType.COLD] = resolvers.mbonus_material(20, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.COLD] = resolvers.mbonus_material(10, 10),
		},
		stats_on_block={
			on_melee_hit = {
				[DamageType.ICE] = resolvers.mbonus_material(30, 20),
			},
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "arcane ", prefix=true, instant_resolve=true,
	keywords = {arcane=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	special_combat = {
		melee_project = {
			[DamageType.ARCANE] = resolvers.mbonus_material(20, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.ARCANE] = resolvers.mbonus_material(10, 10),
		},
		stats_on_block={
			on_melee_hit = {
				[DamageType.ARCANE] = resolvers.mbonus_material(30, 20),
			},
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "blade's ", prefix=true, instant_resolve=true,
	keywords = {blades=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		max_mana=resolvers.mbonus_material(30, 20),
		fatigue = resolvers.mbonus_material(10, 2, function(e, v) return 0, -v end),
		stats_on_block={mana_regen_when_hit = resolvers.mbonus_material(20, 2)},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "thunderous ", prefix=true, instant_resolve=true,
	keywords = {thunderous=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		resists={
			[DamageType.LIGHTNING] = resolvers.mbonus_material(10, 10),
		},
	},
	on_block = {desc = "If this damage hit ends your block, release all blocked damage as a radius 2 lightning damage explosion.", fct = function(self, who, target, type, dam, eff)
		if not eff.dur then return end
		if who.turn_procs and who.turn_procs.thunderous then return end

		-- Set this *before* damage or reflect/martyr avoids the limit
		if not who.turn_procs.thunderous then who.turn_procs.thunderous = true end
		
		local tg = {type="ball", range=0, radius=2}
		local damage = dam

		who:project(tg, who.x, who.y, engine.DamageType.LIGHTNING, damage)
		game.level.map:particleEmitter(who.x, who.y, 2, "ball_lightning", {radius=2})
		who:logCombat("#Source# unleashes thunderous retribution!")
	end,},
}
newEntity{
	power_source = {arcane=true},
	name = "bone ", prefix=true, instant_resolve=true,
	keywords = {bone=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={
			[DamageType.DARKNESS] = resolvers.mbonus_material(10, 10),
		},
		resists_actor_type={
			["undead"] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "demonic ", prefix=true, instant_resolve=true,
	keywords = {demonic=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	special_combat = {
		melee_project = {
			[DamageType.BLIGHT] = resolvers.mbonus_material(20, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.FIRE] = resolvers.mbonus_material(10, 10),
		},
		max_vim=resolvers.mbonus_material(20, 10),
	},
}

----------------------------------------------------------------
-- Arcane Greater Egos
----------------------------------------------------------------
newEntity{
	power_source = {arcane=true},
	name = "crackling ", prefix=true, instant_resolve=true,
	keywords = {crackling=true},
	level_range = {1, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 60,
	special_combat = {
		melee_project = {
			[DamageType.LIGHTNING] = resolvers.mbonus_material(10, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.LIGHTNING] = resolvers.mbonus_material(10, 10),
		},
		inc_stats = {
			[Stats.STAT_STR] = resolvers.mbonus_material(5, 1),
		},
		stats_on_block={
			on_melee_hit = {
				[DamageType.ITEM_LIGHTNING_DAZE] = resolvers.mbonus_material(30, 20),
			},
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "corrosive ", prefix=true, instant_resolve=true,
	keywords = {corrosive=true},
	level_range = {1, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 60,
	special_combat = {
		melee_project = {
			[DamageType.ACID] = resolvers.mbonus_material(10, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.ACID] = resolvers.mbonus_material(10, 10),
		},
		inc_stats = {
			[Stats.STAT_CON] = resolvers.mbonus_material(5, 1),
		},
		stats_on_block={
			on_melee_hit = {
				[DamageType.ITEM_ACID_CORRODE] = resolvers.mbonus_material(30, 20),
			},
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "warded ", prefix=true, instant_resolve=true,
	keywords = {ward=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		special_on_hit = {desc="reduce the cooldown of your ward talent by 1", fct=function(combat, who, target)
		if who.talents_cd[who.T_WARD] then
			who.talents_cd[who.T_WARD] = who.talents_cd[who.T_WARD] - 1
		end
			
		end},
	},
	wielder = {
		wards = {
			[DamageType.FIRE] = resolvers.mbonus_material(5, 1),
			[DamageType.COLD] = resolvers.mbonus_material(5, 1),
			[DamageType.LIGHTNING] = resolvers.mbonus_material(5, 1),
			[DamageType.TEMPORAL] = resolvers.mbonus_material(5, 1),
			[DamageType.BLIGHT] = resolvers.mbonus_material(5, 1),
		},
		learn_talent = {[Talents.T_WARD] = 1},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "cosmic ", prefix=true, instant_resolve=true,
	keywords = {cosmic=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		burst_on_crit={
			[DamageType.LIGHT] = resolvers.mbonus_material(30, 10),
			[DamageType.DARKNESS] = resolvers.mbonus_material(30, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.LIGHT] = resolvers.mbonus_material(10, 5),
			[DamageType.DARKNESS] = resolvers.mbonus_material(10, 5),
		},
	},
	on_block = {desc = "Unleash the fury of the cosmos, dealing light and darkness damage (scales with your magic) to your attackers", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			if who.turn_procs and who.turn_procs.shield_cosmic and who.turn_procs.shield_cosmic[target.uid] then return end

			-- Set this *before* damage or reflect/martyr avoids the limit
			if not who.turn_procs.shield_cosmic then who.turn_procs.shield_cosmic = {} end
			who.turn_procs.shield_cosmic[target.uid] = true
			
			local tg = {type="hit", range=10}
			local damage = who:getStat("mag")

			who:project(tg, target.x, target.y, engine.DamageType.DARKNESS, damage)
			who:project(tg, target.x, target.y, engine.DamageType.LIGHT, damage)
			who:logCombat(target, "#Source# unleashes cosmic retribution at #Target#!")
			

	end,},
}
newEntity{
	power_source = {arcane=true},
	name = " of patience", suffix=true, instant_resolve=true,
	keywords = {patience=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	resolvers.charmt(Talents.T_TIME_SHIELD, {1,2,3,4}, 30 ), --Reduced activation level since this talent was buffed...
	special_combat = {
		melee_project={
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10)
		},
	},
	wielder = {
		resists={
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10),
		},
		on_melee_hit = {
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = " of radiance", suffix=true, instant_resolve=true,
	keywords = {radiance=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project={
			[DamageType.LIGHT] = resolvers.mbonus_material(10, 10),
			[DamageType.ITEM_LIGHT_BLIND] = resolvers.mbonus_material(10, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.LIGHT] = resolvers.mbonus_material(10, 10),
		},
		inc_stats = {
			[Stats.STAT_MAG] = resolvers.mbonus_material(5, 1),
		},
		on_melee_hit = {
			[DamageType.ITEM_LIGHT_BLIND] = resolvers.mbonus_material(30, 10),
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "aetheric ", prefix=true, instant_resolve=true,
	keywords = {aetheric=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		melee_project={
			[DamageType.ARCANE] = resolvers.mbonus_material(10, 10),
		},
	},
	wielder = {
		resists={
			[DamageType.ARCANE] = resolvers.mbonus_material(10, 10),
		},
		mana_regen = resolvers.mbonus_material(5, 1, function(e, v) return 0, v/2 end),
	},
	on_block = {desc = "Lowers the cooldown of one of your spells at random by 1 turn", fct = function(self, who, target, type, dam, eff)
		local tids = {}
		for tid, _ in pairs(who.talents_cd) do
			local tt = who:getTalentFromId(tid)
			if not tt.fixed_cooldown then
				if tt.is_spell then
					tids[#tids+1] = tid
				end
			end
		end
		if #tids == 0 then return end
		local tid = rng.tableRemove(tids)
		who.talents_cd[tid] = who.talents_cd[tid] - 1
	end,},
}
newEntity{
	power_source = {arcane=true},
	name = "rune scarred ", prefix=true, instant_resolve=true,
	keywords = {['rune scarred']=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project = {
			[DamageType.ARCANE_SILENCE] = resolvers.mbonus_material(10, 10),
		},
	},
	wielder = {
		fatigue = resolvers.mbonus_material(10, 2, function(e, v) return 0, -v end),
		stats_on_block={
			combat_spellresist = resolvers.mbonus_material(40, 10),
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = " of faith", suffix=true, instant_resolve=true,
	keywords = {faith=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		combat_spellresist = resolvers.mbonus_material(10, 5),
		combat_mentalresist = resolvers.mbonus_material(10, 5),
		shield_factor = resolvers.mbonus_material(10, 5),
	},
}
newEntity{
	power_source = {arcane=true},
	name = " of displacement", suffix=true, instant_resolve=true,
	keywords = {displacement=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		melee_project={
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10)
		},
		reflective = true,
	},
	wielder = {
		combat_def = resolvers.mbonus_material(10, 5),
	},
}
newEntity{
	power_source = {arcane=true},
	name = " of stasis", suffix=true, instant_resolve=true,
	keywords = {stasis=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		melee_project={
			[DamageType.ICE_SLOW] = resolvers.mbonus_material(10, 10)
		},
	},
	wielder = {
		slow_projectiles = resolvers.mbonus_material(20, 10),
		resists={
			[DamageType.COLD] = resolvers.mbonus_material(10, 10),
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 10),
		},
	},
}
newEntity{
	power_source = {arcane=true},
	name = "life eating ", prefix=true, instant_resolve=true,
	keywords = {['life eating']=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	special_combat = {
		lifesteal=resolvers.mbonus_material(10, 5),
		bloodruned = true,
	},
	wielder = {
	},
}

newEntity{
	power_source = {arcane=true},
	name = "golem's ", prefix=true, instant_resolve=true,
	keywords = {['golem']=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	wielder = {
		combat_armor = resolvers.mbonus_material(8, 4),
		combat_armor_hardiness = 10,
		stun_immune = resolvers.mbonus_material(30, 20, function(e, v) return 0, v/100 end),
		talents_types_mastery = {
			["golem/fighting"] = resolvers.mbonus_material(10, 10, function(e, v) v=v/100 return 0, v end),
			["golem/arcane"] = resolvers.mbonus_material(10, 10, function(e, v) v=v/100 return 0, v end),
		},
	},
}

----------------------------------------------------------------
-- Antimagic Lesser Egos
----------------------------------------------------------------
newEntity{
	power_source = {antimagic=true},
	name = " of arcane resistance", suffix=true, instant_resolve=true,
	keywords = {arcane=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		resists={[DamageType.ARCANE] = resolvers.mbonus_material(10, 10)},
		stats_on_block={
			combat_spellresist = resolvers.mbonus_material(40, 10),
		},
	},
}
newEntity{
	power_source = {antimagic=true},
	name = "fungal ", prefix=true, instant_resolve=true,
	keywords = {fungal=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	wielder = {
		healing_factor = resolvers.mbonus_material(20, 10, function(e, v) v=v/100 return 0, v end),
		inc_stats = {
			[Stats.STAT_CON] = resolvers.mbonus_material(5, 1),
		},
	},
}
newEntity{
	power_source = {antimagic=true},
	name = "mage hunting ", prefix=true, instant_resolve=true,
	keywords = {['mage hunt']=true},
	level_range = {1, 50},
	rarity = 5,
	cost = 5,
	wielder = {
		combat_spellresist = resolvers.mbonus_material(10, 5),
		talents_types_mastery = {
			["wild-gift/antimagic"] = resolvers.mbonus_material(10, 10, function(e, v) v=v/100 return 0, v end),
		},
	},
}
newEntity{
	power_source = {antimagic=true},
	name = " of negation", suffix=true, instant_resolve=true,
	keywords = {negation=true},
	level_range = {10, 50},
	rarity = 10,
	cost = 10,
	special_combat = {
		melee_project = {
			[DamageType.ITEM_ANTIMAGIC_SCOURING] = resolvers.mbonus_material(20, 15),
		},
	},
	wielder = {
	},
	resolvers.charmt(Talents.T_DESTROY_MAGIC, {1,2,3}, 30 ),
}

----------------------------------------------------------------
-- Antimagic Greater Egos
----------------------------------------------------------------
newEntity{
	power_source = {antimagic=true},
	name = "sappy ", prefix=true, instant_resolve=true,
	keywords = {sappy=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	special_combat = {
		melee_project = {
			[DamageType.NATURE] = resolvers.mbonus_material(10, 10),
			[DamageType.ITEM_ANTIMAGIC_MANABURN] = resolvers.mbonus_material(10, 10),
		},
	},
	on_block = {desc = "Attacker is disarmed", fct = function(self, who, target, type, dam, eff)
			if not target or target:attr("dead") or not target.x or not target.y then return end
			if target:canBe("disarm") then
				target:setEffect(target.EFF_DISARM, 4, {src=who, apply_power=who:combatAttack(combat)})
			end
	end,},
	wielder = {
	},
}
newEntity{
	power_source = {antimagic=true},
	name = "immutable ", prefix=true, instant_resolve=true,
	keywords = {immutable=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	wielder = {
		combat_armor = resolvers.mbonus_material(8, 4),
		resists={
			[DamageType.ARCANE] = resolvers.mbonus_material(10, 5),
			[DamageType.TEMPORAL] = resolvers.mbonus_material(10, 5),
			[DamageType.BLIGHT] = resolvers.mbonus_material(10, 5),
			[DamageType.ACID] = resolvers.mbonus_material(10, 5),
		},
	},
}
newEntity{
	power_source = {antimagic=true},
	name = " of blight hunting", suffix=true, instant_resolve=true,
	keywords = {['blight hunt']=true},
	level_range = {20, 50},
	greater_ego = 1,
	rarity = 20,
	cost = 20,
	wielder = {
		resists={
			[DamageType.BLIGHT] = resolvers.mbonus_material(10, 10),
			[DamageType.DARKNESS] = resolvers.mbonus_material(10, 10),
		},
		combat_spellresist = resolvers.mbonus_material(10, 10),
	},
}
newEntity{
	power_source = {antimagic=true},
	name = " of horror slaying", suffix=true, instant_resolve=true,
	keywords = {['h. slaying']=true},
	level_range = {30, 50},
	greater_ego = 1,
	rarity = 30,
	cost = 30,
	wielder = {
		resists_actor_type = {unnatural=resolvers.mbonus_material(10, 10)},
		inc_damage_actor_type = {unnatural=resolvers.mbonus_material(10, 10)},
		combat_mentalresist = resolvers.mbonus_material(10, 10),
	},
}
